cmd

package
v0.0.0-...-976a2c0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 24, 2026 License: MIT Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	Version   = "0.2.0"   // Will be set during build with ldflags
	Commit    = "unknown" // Will be set during build with ldflags
	BuildDate = "unknown" // Will be set during build with ldflags
)

Version information - updated during build

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

Types

This section is empty.

Jump to